@@ -144,6 +144,13 @@ class CustomFormatter(logging.Formatter):
         return super().format(record)
 
 
+class ExcludeProfilingStreamHandler(logging.StreamHandler):
+
+    def emit(self, record: logging.LogRecord) -> None:
+        if record.levelno != 7:
+            return super().emit(record)
+
+
 def _each_run_file_rotate_handler(in_file_name, in_back_up):
     _date_format = DATEFORMAT_DEV if os.getenv('IS_DEV') == "1" else DATEFORMAT_STD
     formatter = CustomFormatter(fmt='{asctime}.{msecs:03.0f} |{levelname:^11}|{threadName:^12}|{lineno:^5}| {name:<50} |{funcName:^30}||--> {message}', datefmt=_date_format, style='{')
@@ -157,7 +164,7 @@ def _stdout_handler():
     _date_format = DATEFORMAT_DEV
     formatter = CustomFormatter(fmt='{asctime} |{levelname:^11}| {name:<50} |{funcName:^30}||--> {message}', datefmt=_date_format, style='{')
     # formatter = logging.Formatter(fmt='[{asctime}][{levelname:^7}][{name:<30}][{funcName:^25}] --> {message}', datefmt=_date_format, style='{')
-    handler = logging.StreamHandler()
+    handler = ExcludeProfilingStreamHandler()
     handler.setFormatter(formatter)
     return handler
 
